from sqlalchemy import Column, Integer, String, Text, Boolean, DateTime
from sqlalchemy.sql import func
from app.db.base import Base

class Rule(Base):
    __tablename__ = "rules"

    id = Column(Integer, primary_key=True, index=True)
    name = Column(String, unique=True, index=True, nullable=False)
    description = Column(Text, nullable=True)
    rule_type = Column(String, nullable=False)  # velocity, amount_limit, blacklist, pattern, etc.
    conditions = Column(Text, nullable=False)  # JSON string with rule conditions
    actions = Column(Text, nullable=False)  # JSON string with actions to take
    priority = Column(Integer, default=1)  # Higher number = higher priority
    is_active = Column(Boolean, default=True)
    version = Column(Integer, default=1)
    created_by = Column(String, nullable=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())

class RuleVersion(Base):
    __tablename__ = "rule_versions"

    id = Column(Integer, primary_key=True, index=True)
    rule_id = Column(Integer, nullable=False, index=True)
    version = Column(Integer, nullable=False)
    name = Column(String, nullable=False)
    description = Column(Text, nullable=True)
    rule_type = Column(String, nullable=False)
    conditions = Column(Text, nullable=False)
    actions = Column(Text, nullable=False)
    priority = Column(Integer, default=1)
    created_by = Column(String, nullable=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())